import os
import sys
import pylast
import keyring
from dateutil.parser import parse


def get_keys():
    username = os.getenv("USER", "")
    keys = keyring.get_password('lastfm_keys', username)
    if keys is None:
        url = "http://www.last.fm/api/account"
        keys = raw_input(
            "Enter your keys (<API_KEY>:<SECRET_KEY>) from %s>  " % url)
        keyring.set_password('lastfm_keys', username, keys)
    return keys.split(":")


def main():
    args = sys.argv[1:]
    if len(args) < 1:
        print "ERROR: please provide a username"
        sys.exit(1)
    username = args[0]
    api_key, secret_key = get_keys()
    network = pylast.get_lastfm_network(api_key, secret_key)
    user = network.get_user(username)
    now_playing = user.get_now_playing()
    if now_playing is None:
        print "%s is not currently playing anything" % username
        sys.exit(1)
    artist = now_playing.artist
    album = now_playing.get_album()
    song = now_playing.get_name()
    release_date = album.get_release_date()
    date = parse(release_date)
    year = date.year
    # get the album name by stripping the artist out of it
    album = str(album).strip("%s - " % str(artist))
    # print it all out
    print "%(song)s - %(album)s (%(year)s) - %(artist)s" % locals()


if __name__ == '__main__':
    main()
